<?php 

namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Notification;

use Teknisa\CNC\Services;
use Teknisa\Libs\Util\Environment;

class Cnc01600CadastroEstabelecimento extends \Teknisa\CNC\Controllers\TeknisaCrud {
	protected $service;
	protected $environment;
	
	public function __construct (Services\Cnc01600CadastroEstabelecimentoService $service, Environment $environment) {
        $this->service = $service;
        $this->environment = $environment;
	}
	
	private function getLikeConditions($params) {
        $likeConditions = [];
        
        foreach($params as $param) {
            if($param['operator'] === 'MAPPED_LIKE_ALL')
                $likeConditions['ALL_FIELDS'] = $param['value'];
        }
        
        return $likeConditions;
	}

	public function getEstabelecParam(DTO\Request $request, DTO\Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();
            
            $likeConditions = $this->getLikeConditions($params);

            $resultadoFiltrado = $this->service->getEstabelecParam($likeConditions);

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('cnc01600_estabelec', $resultadoFiltrado));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function getSeries(DTO\Request $request, DTO\Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $resultadoFiltrado = $this->service->getSeries($params);

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('cnc01600_estabelecimento_series', $resultadoFiltrado));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function getContaRec(DTO\Request $request, DTO\Response $response){
        try {

            $resultadoFiltrado = $this->service->getContaRec();

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('cnc01600_estabelecimento_contaRecebe', $resultadoFiltrado));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function getTpAjuste(DTO\Request $request, DTO\Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $resultadoFiltrado = $this->service->getTpAjuste();

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('cnc01600_estabelecimento_tpAjuste', $resultadoFiltrado));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function getTpDebito(DTO\Request $request, DTO\Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $resultadoFiltrado = $this->service->getTpDebito();

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('cnc01600_estabelecimento_tpDebito', $resultadoFiltrado));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function getTpCredito(DTO\Request $request, DTO\Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $resultadoFiltrado = $this->service->getTpCredito();

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('cnc01600_estabelecimento_tpCredito', $resultadoFiltrado));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
	
	public function saveEstabelec (DTO\Request $request, DTO\Response $response) {
	    try {
    	    $row = $request->getDataSet()->getRows()[0];
    	    
            $row["NRORG"] = $this->environment->getNrOrgTrab();
            $row["IDATIVO"] = "S";
            $row["DTULTATU"] = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
            $row["CDOPERULTATU"] = $this->environment->getCdOperador();
                    
            $this->service->saveEstabelec($row);
            $response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS);
	    
	    } catch (\Exception $e) {
	        $response->setError(new Error($e->getMessage(), $e->getCode()));
	    }
	}
	
	public function saveEstabelecName (DTO\Request $request, DTO\Response $response) {
	    try {
    	    $row = $request->getDataSet()->getRows()[0];
    	    
            $row["NRORG"] = $this->environment->getNrOrgTrab();
            $row["IDATIVO"] = "S";
            $row["DTULTATU"] = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
            $row["CDOPERULTATU"] = $this->environment->getCdOperador();
                    
            $this->service->saveEstabelecName($row);
            $response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS);
	    
	    } catch (\Exception $e) {
	        $response->setError(new Error($e->getMessage(), $e->getCode()));
	    }
	}


	public function saveFinancEstabelec (DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getDataSet()->getRows()[0];
            
            $row["NRORG"] = $this->environment->getNrOrgTrab();
            $row["IDATIVO"] = "S";
            $row["DTULTATU"] = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
            $row["CDOPERULTATU"] = $this->environment->getCdOperador();
            
            $result = $this->service->saveFinancEstabelec($row);
            $result ?
                $response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS)
                    :
                $response->addNotification(new Notification("Ocorreu um erro."), Notification::TYPE_ERROR);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

	public function getAgencias (DTO\Request\Filter $request, DTO\Response $response) {
		try {
			$row = $request->getFilterCriteria()->getConditions();
			$dataSet = $this->service->getAgencias($row);
			$response->addDataSet(new DataSet('dataSet', $dataSet));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}
	
	public function getContas (DTO\Request\Filter $request, DTO\Response $response) {
		try {
			$row = $request->getFilterCriteria()->getConditions();
			$dataSet = $this->service->getContas($row);
			$response->addDataSet(new DataSet('dataSet', $dataSet));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}

	public function getBancoMasks (DTO\Request\Filter $request, DTO\Response $response) {
	    try {
	        $row = $request->getFilterCriteria()->getConditions();
	        $dataSet = $this->movFinanceiraService->getBancoMasks($row[0]['value']);

	        $response->addDataSet(new DataSet('dataSet', $dataSet));
	    } catch (\Exception $e) {
	        $response->setError(new Error($e->getMessage(), $e->getCode()));
	    }
	}

	public function getFilialParams (DTO\Request\Filter $request, DTO\Response $response) {
	    try {
    	    $row =  $request->getFilterCriteria()->getConditions();
    	    $dataSet = $this->service->getFilialParams($row);
	        $response->addDataSet(new DataSet('dataSet', $dataSet));
	    } catch (\Exception $e) {
	        $response->setError(new Error($e->getMessage(), $e->getCode()));
	    }
	}
}